import os


FPS = 30
IMAGE_DIR = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'images')
STARTING_FEN = "rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR w KQkq - 0 1"
WINDOW_CAPTION = "chess-board"
WINDOW_HEIGHT = 600
WINDOW_WIDTH = 600
